
%--- Simulation settings ---%
simulation = {
    time = {
        start = 0;      %   [s]     Start time
        end = 16;       %   [s]     End time of simulation
        dt = 1e-4;      %   [s]     Time step size
        % cfl = 0.9;    % use adaptive time step based on max courant number
    }
    print = {
        dt = 1e-2;    % save results every xx time interval
        % format = "ascii"
    }
    statics.solve = 0; % do not solve static system (intended for rigid body equilibrium)
} 

%--- Environmental settings ---%
environment = {
    gravity = -9.81;        % [m/s2]    Gravitational acceleration
    waterLevel = 3;         % [m]       z-coordinate of mean water level
    waterDensity = 1e3;     % [kg/m3]   Density of water
    airDensity = 0.0;       % [kg/m3]   Density of air

    %--- Ground model input  ----%
    ground = {
        level = 0;
        type = 'springDamp';
        % damping = 1e4;
        dampingCoeff = 1; % ratio of critical damping for each cable
        frictionCoeff = 0.3;
        frictionVelocity = 0.01;
        stiffness = 3e9;    
        oneWayDamping = 0;                       
    }
    
} % end environment


%--- List of vertices ---%
%                       no.     x       y       z                     
vertexLocations =       {   
                        1     [ 0       0      0 ];
                        2     [ 32.554      0    3.3]
                        };                    

%---Cable types---%
cableType1 = {
    diameter = 0.0022;
    rho = 7800;
    gamma0 = 0.0818;
    CDn = 2.5;
    CDt = 0.5;
    CMn = 3.8;
    materialModel = {
        EA = 1e4; 
        xi = 2;
        type = 'bilinear';
    }
}

%----- Cables -----%
cable1 = {
    typeNumber = 1;
    vertex0 = 1; %
    vertex1 = 2; %
    length = 33; %
    IC.type = 'catenary'; 
    mesh.N =   20;   %
}

%--- Boundary Conditions ---%
bc1 = {
    vertex = 1;    
}
bc2 = {
    vertex = 2;
    mode = "sine";
    rotationMode = "pinned";
    % if scalar values, it is applied to all dimensions:
    amplitude = [0.2;0;-0.2];       % [m]
    frequency = [0.8;0.8;0.8];      % [Hz]
    phase = [90;0;0];               % [deg]
    centerValue = [32.554;0;3.3];   % [m]
    rampTime = 2.5;                 % [s]
}        

